@@ -9,24 +9,19 @@
 #ifndef KFINDTEST_H
 #define KFINDTEST_H
 
-#include <ktextwidgets_export.h>
 #include <QObject>
 #include <QStringList>
-
+#include <ktextwidgets_export.h>
+#include <memory>
 class KFind;
-
 class KFindRecorder : public QObject
 {
     Q_OBJECT
 
 public:
-    explicit KFindRecorder(const QStringList &text) :
-        QObject(nullptr),
-        m_find(nullptr),
-        m_text(text),
-        m_line(0)
-    {}
+    explicit KFindRecorder(const QStringList &text);
 
+    ~KFindRecorder() override;
     void find(const QString &pattern, long options = 0);
     bool findNext(const QString &pattern = QString());
 
@@ -46,10 +41,10 @@ public Q_SLOTS:
     void slotHighlight(int id, int index, int matchedLengthlength);
 
 private:
-    KFind                 *m_find;
-    QStringList            m_text;
-    int                   m_line;
-    QStringList            m_hits;
+    std::unique_ptr<KFind> m_find;
+    QStringList m_text;
+    int m_line;
+    QStringList m_hits;
 };
 
 class TestKFind : public QObject
@@ -61,20 +56,15 @@ public:
 
 private Q_SLOTS:
 
-#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
-    void testStaticFindString_data();
-    void testStaticFindString();
-#endif
     void testStaticFindRegexp_data();
     void testStaticFindRegexp();
 
+    void testRegexpUnicode_data();
+    void testRegexpUnicode();
+
     void testSimpleSearch();
     void testSimpleRegexp();
 
-#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
-    void testLineBeginRegexp();
-#endif
-
     void testLineBeginRegularExpression();
     void testFindIncremental();
     void testFindIncrementalDynamic();
